@@ -1,8 +1,8 @@
 import ctypes
 from .agora_base import *
 from .local_user import *
-from .local_user_observer import *
-from .remote_video_track import RemoteVideoTrack
+from .remote_audio_track import RemoteAudioTrack, RemoteAudioTrackStats
+from .remote_video_track import RemoteVideoTrack, RemoteVideoTrackStats
 uid_t = ctypes.c_uint
 track_id_t = ctypes.c_uint
 
@@ -10,21 +10,6 @@ track_id_t = ctypes.c_uint
 
 
 
-class RemoteAudioTrackStats(ctypes.Structure):
-    _fields_ = [
-        ("uid", ctypes.c_uint),
-        ("quality", ctypes.c_int),
-        ("network_transport_delay", ctypes.c_int),
-        ("jitter_buffer_delay", ctypes.c_int),
-        ("audio_loss_rate", ctypes.c_int),
-        ("num_channels", ctypes.c_int),
-        ("received_sample_rate", ctypes.c_int),
-        ("received_bitrate", ctypes.c_int),
-        ("total_frozen_time", ctypes.c_int),
-        ("frozen_rate", ctypes.c_int),
-        ("received_bytes", ctypes.c_int64)
-    ]
-
 class VideoTrackInfoInner(ctypes.Structure):
     _fields_ = [
         ("is_local", ctypes.c_int),
@@ -51,56 +36,6 @@ class VideoTrackInfoInner(ctypes.Structure):
         track_info.owner_uid = self.owner_uid
         return track_info
 
-    
-
-class LocalVideoTrackStats(ctypes.Structure):
- _fields_ = [
-        ("number_of_streams", ctypes.c_uint64),
-        ("bytes_major_stream", ctypes.c_uint64),
-        ("bytes_minor_stream", ctypes.c_uint64),
-        ("frames_encoded", ctypes.c_uint32),
-        ("ssrc_major_stream", ctypes.c_uint32),
-        ("ssrc_minor_stream", ctypes.c_uint32),
-        ("capture_frame_rate", ctypes.c_int),
-        ("regulated_capture_frame_rate", ctypes.c_int),
-        ("input_frame_rate", ctypes.c_int),
-        ("encode_frame_rate", ctypes.c_int),
-        ("render_frame_rate", ctypes.c_int),
-        ("target_media_bitrate_bps", ctypes.c_int),
-        ("media_bitrate_bps", ctypes.c_int),
-        ("total_bitrate_bps", ctypes.c_int),
-        ("capture_width", ctypes.c_int),
-        ("capture_height", ctypes.c_int),
-        ("regulated_capture_width", ctypes.c_int),
-        ("regulated_capture_height", ctypes.c_int),
-        ("width", ctypes.c_int),
-        ("height", ctypes.c_int),
-        ("encoder_type", ctypes.c_uint32),
-        ("uplink_cost_time_ms", ctypes.c_uint32),
-        ("quality_adapt_indication", ctypes.c_int)
-    ]
-class RemoteVideoTrackStats(ctypes.Structure):
-    _fields_ = [
-        ("uid", ctypes.c_uint),
-        ("delay", ctypes.c_int),
-        ("width", ctypes.c_int),
-        ("height", ctypes.c_int),
-        ("received_bitrate", ctypes.c_int),
-        ("decoder_output_frame_rate", ctypes.c_int),
-        ("renderer_output_frame_rate", ctypes.c_int),
-        ("frame_loss_rate", ctypes.c_int),
-        ("packet_loss_rate", ctypes.c_int),
-        ("rx_stream_type", ctypes.c_int),
-        ("total_frozen_time", ctypes.c_int),
-        ("frozen_rate", ctypes.c_int),
-        ("total_decoded_frames", ctypes.c_uint32),
-        ("av_sync_time_ms", ctypes.c_int),
-        ("downlink_process_time_ms", ctypes.c_uint32),
-        ("frame_render_delay_ms", ctypes.c_uint32),
-        ("totalActiveTime", ctypes.c_uint64),
-        ("publishDuration", ctypes.c_uint64)
-    ]
-
 class AudioVolumeInfo(ctypes.Structure):
     _fields_ = [
         ("user_id", ctypes.c_uint),
@@ -338,7 +273,7 @@ class RTCLocalUserObserverInner(ctypes.Structure):
         self.local_user_observer.on_user_audio_track_subscribed(self.local_user, user_id_str, remote_audio_track)
 
     def _on_remote_audio_track_statistics(self, local_user_handle, remote_audio_track_handle, stats):
-        print("LocalUserCB _on_remote_audio_track_statistics:", local_user_handle, remote_audio_track_handle, stats)
+        # print("LocalUserCB _on_remote_audio_track_statistics:", local_user_handle, remote_audio_track_handle, stats)
         audio_stats = stats.contents #RemoteAudioTrackStats
         remote_audio_track = self.local_user.get_remote_audio_map(remote_audio_track_handle)
         self.local_user_observer.on_remote_audio_track_statistics(self.local_user, remote_audio_track, audio_stats)
@@ -480,10 +415,10 @@ class RTCLocalUserObserverInner(ctypes.Structure):
         self.local_user_observer.on_remote_subscribe_fallback_to_audio_only(self.local_user, user_id_str, is_fallback)
 
     def _on_stream_message(self, local_user_handle, user_id, stream_id, data, size):
-        print("LocalUserCB _on_stream_message:", local_user_handle, user_id, stream_id, data, size)
+        # print("LocalUserCB _on_stream_message:", local_user_handle, user_id, stream_id, data, size)
         user_id_str = user_id.decode('utf-8') if user_id else ""
         bytes_from_c = ctypes.string_at(data, size)  
-        data_byte_array = bytearray(bytes_from_c)     
+        data_byte_array = bytearray(bytes_from_c).decode()     
         #note: do not use date_byte_array.decode()  for the stream msg is binary data, not limited to only text
         self.local_user_observer.on_stream_message(self.local_user, user_id_str, stream_id, data_byte_array, size)
 
